"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createIndexesTaskDefinition = void 0;
var _tasks = require("@webiny/tasks");
var _CreateIndexesTaskRunner = require("./CreateIndexesTaskRunner");
const createIndexesTaskDefinition = params => {
  return (0, _tasks.createTaskDefinition)({
    id: "elasticsearchCreateIndexes",
    title: "Create Missing Elasticsearch Indexes",
    /**
     * Maximum number of iterations before the task goes into the error state.
     * No point in having more than 2 runs, as the create index operations should not even take 1 full run, no matter how much indeexs is there to create.
     */
    maxIterations: 2,
    run: async ({
      response,
      context,
      isCloseToTimeout,
      isAborted,
      store,
      input,
      timer
    }) => {
      const {
        Manager
      } = await import(/* webpackChunkName: "Manager" */"../Manager");
      const {
        IndexManager
      } = await import(/* webpackChunkName: "IndexManager" */"../../settings");
      const manager = new Manager({
        elasticsearchClient: params?.elasticsearchClient,
        documentClient: params?.documentClient,
        response,
        context,
        isAborted,
        isCloseToTimeout,
        store,
        timer
      });
      const indexManager = new IndexManager(manager.elasticsearch, {});
      const createIndexesTaskRunner = new _CreateIndexesTaskRunner.CreateIndexesTaskRunner(manager, indexManager);
      return createIndexesTaskRunner.execute(input.matching, Array.from(input.done || []));
    },
    async onBeforeTrigger({
      context
    }) {
      // Let's create a new index for the tasks first.
      const {
        IndexManager
      } = await import(/* webpackChunkName: "IndexManager" */"../../settings");
      const indexManager = new IndexManager(context.elasticsearch, {});
      const {
        OnBeforeTrigger
      } = await import(/* webpackChunkName: "OnBeforeTrigger" */"./OnBeforeTrigger");
      const onBeforeTrigger = new OnBeforeTrigger({
        indexManager,
        context
      });
      await onBeforeTrigger.run(["webinytask"]);
    }
  });
};
exports.createIndexesTaskDefinition = createIndexesTaskDefinition;

//# sourceMappingURL=index.js.map